@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.8.11 (default, Aug  3 2021, 15:09:35)  [GCC 7.5.0]
+# Python 3.9.7 (default, Sep 10 2021, 14:59:43)  [GCC 11.2.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -195,6 +195,33 @@ except ModulenotfoundExp_ as exp:
                 return self.__name
             def dst(self, dt):
                 return None
+        def __str__(self):
+            settings = {
+                'str_pretty_print': True,
+                'str_indent_level': 0,
+                'str_namespaceprefix': '',
+                'str_name': None,
+                'str_namespacedefs': '',
+            }
+            for n in settings:
+                if hasattr(self, n):
+                    setattr(settings[n], self[n])
+            if sys.version_info.major == 2:
+                from StringIO import StringIO
+            else:
+                from io import StringIO
+            output = StringIO()
+            self.export(
+                output,
+                settings['str_indent_level'],
+                pretty_print=settings['str_pretty_print'],
+                namespaceprefix_=settings['str_namespaceprefix'],
+                name_=settings['str_name'],
+                namespacedef_=settings['str_namespacedefs']
+            )
+            strval = output.getvalue()
+            output.close()
+            return strval
         def gds_format_string(self, input_data, input_name=''):
             return input_data
         def gds_parse_string(self, input_data, node=None, input_name=''):
@@ -205,11 +232,11 @@ except ModulenotfoundExp_ as exp:
             else:
                 return input_data
         def gds_format_base64(self, input_data, input_name=''):
-            return base64.b64encode(input_data)
+            return base64.b64encode(input_data).decode('ascii')
         def gds_validate_base64(self, input_data, node=None, input_name=''):
             return input_data
         def gds_format_integer(self, input_data, input_name=''):
-            return '%d' % input_data
+            return '%d' % int(input_data)
         def gds_parse_integer(self, input_data, node=None, input_name=''):
             try:
                 ival = int(input_data)
@@ -236,7 +263,7 @@ except ModulenotfoundExp_ as exp:
                     raise_parse_error(node, 'Requires sequence of integer values')
             return values
         def gds_format_float(self, input_data, input_name=''):
-            return ('%.15f' % input_data).rstrip('0')
+            return ('%.15f' % float(input_data)).rstrip('0')
         def gds_parse_float(self, input_data, node=None, input_name=''):
             try:
                 fval_ = float(input_data)
@@ -878,7 +905,7 @@ class MixedContainer:
                 self.name,
                 base64.b64encode(self.value),
                 self.name))
-    def to_etree(self, element, mapping_=None, nsmap_=None):
+    def to_etree(self, element, mapping_=None, reverse_mapping_=None, nsmap_=None):
         if self.category == MixedContainer.CategoryText:
             # Prevent exporting empty content as empty lines.
             if self.value.strip():
@@ -898,7 +925,7 @@ class MixedContainer:
             subelement.text = self.to_etree_simple()
         else:    # category == MixedContainer.CategoryComplex
             self.value.to_etree(element)
-    def to_etree_simple(self, mapping_=None, nsmap_=None):
+    def to_etree_simple(self, mapping_=None, reverse_mapping_=None, nsmap_=None):
         if self.content_type == MixedContainer.TypeString:
             text = self.value
         elif (self.content_type == MixedContainer.TypeInteger or
@@ -979,15 +1006,15 @@ def _cast(typ, value):
 class GetUserReq(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('sequence', 'xsd:unsignedLong', 0, 1, {'use': 'optional'}),
-        MemberSpec_('value01', 'xsd:string', 0, 1, {'use': 'optional'}),
-        MemberSpec_('value02', 'xsd:integer', 0, 1, {'use': 'optional'}),
-        MemberSpec_('value03', 'xsd:string', 0, 1, {'use': 'optional'}),
-        MemberSpec_('value04', 'xsd:integer', 0, 1, {'use': 'optional'}),
-        MemberSpec_('value05', 'xsd:string', 0, 1, {'use': 'optional'}),
-        MemberSpec_('value06', 'xsd:integer', 0, 1, {'use': 'optional'}),
-        MemberSpec_('value07', 'xsd:integer', 0, 1, {'use': 'optional'}),
-        MemberSpec_('value08', 'xsd:string', 0, 1, {'use': 'optional'}),
+        MemberSpec_('sequence', 'xsd:unsignedLong', 0, 1, {'use': 'optional', 'name': 'sequence'}),
+        MemberSpec_('value01', 'xsd:string', 0, 1, {'use': 'optional', 'name': 'value01'}),
+        MemberSpec_('value02', 'xsd:integer', 0, 1, {'use': 'optional', 'name': 'value02'}),
+        MemberSpec_('value03', 'xsd:string', 0, 1, {'use': 'optional', 'name': 'value03'}),
+        MemberSpec_('value04', 'xsd:integer', 0, 1, {'use': 'optional', 'name': 'value04'}),
+        MemberSpec_('value05', 'xsd:string', 0, 1, {'use': 'optional', 'name': 'value05'}),
+        MemberSpec_('value06', 'xsd:integer', 0, 1, {'use': 'optional', 'name': 'value06'}),
+        MemberSpec_('value07', 'xsd:integer', 0, 1, {'use': 'optional', 'name': 'value07'}),
+        MemberSpec_('value08', 'xsd:string', 0, 1, {'use': 'optional', 'name': 'value08'}),
         MemberSpec_('returnedTags', 'xsd:string', 0, 1, {'minOccurs': '0', 'name': 'returnedTags', 'type': 'xsd:string'}, None),
     ]
     subclass = None
