@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.9.5 (default, May 11 2021, 08:20:37)  [GCC 10.3.0]
+# Python 3.9.7 (default, Sep 10 2021, 14:59:43)  [GCC 11.2.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -207,7 +207,10 @@ except ModulenotfoundExp_ as exp:
             for n in settings:
                 if hasattr(self, n):
                     setattr(settings[n], self[n])
-            from io import StringIO
+            if sys.version_info.major == 2:
+                from StringIO import StringIO
+            else:
+                from io import StringIO
             output = StringIO()
             self.export(
                 output,
